Index: /trunk/src/includes/common/formatting.php
===================================================================
--- /trunk/src/includes/common/formatting.php	(revision 5558)
+++ /trunk/src/includes/common/formatting.php	(revision 5559)
@@ -83,5 +83,5 @@
  */
 function bbp_filter_kses( $data = '' ) {
-	return addslashes( wp_kses( stripslashes( $data ), bbp_kses_allowed_tags() ) );
+	return wp_slash( wp_kses( wp_unslash( $data ), bbp_kses_allowed_tags() ) );
 }
 
Index: /trunk/src/includes/common/functions.php
===================================================================
--- /trunk/src/includes/common/functions.php	(revision 5558)
+++ /trunk/src/includes/common/functions.php	(revision 5559)
@@ -702,5 +702,5 @@
 	// @see: http://bbpress.trac.wordpress.org/ticket/2185/
 	// @see: http://core.trac.wordpress.org/changeset/23973/
-	$r = function_exists( 'wp_unslash' ) ? wp_unslash( $r ) : stripslashes_deep( $r );
+	$r = wp_unslash( $r );
 
 	// Prepare duplicate check query
Index: /trunk/src/includes/common/template.php
===================================================================
--- /trunk/src/includes/common/template.php	(revision 5558)
+++ /trunk/src/includes/common/template.php	(revision 5559)
@@ -1298,5 +1298,5 @@
 			case 'text'     :
 			case 'textarea' :
-				$retval = esc_attr( stripslashes( $pre_ret_val ) );
+				$retval = esc_attr( wp_unslash( $pre_ret_val ) );
 				break;
 
Index: /trunk/src/includes/extend/akismet.php
===================================================================
--- /trunk/src/includes/extend/akismet.php	(revision 5558)
+++ /trunk/src/includes/extend/akismet.php	(revision 5559)
@@ -395,5 +395,5 @@
 		// Ready...
 		foreach ( $post_data as $key => $data ) {
-			$query_string .= $key . '=' . urlencode( stripslashes( $data ) ) . '&';
+			$query_string .= $key . '=' . urlencode( wp_unslash( $data ) ) . '&';
 		}
 
@@ -626,11 +626,8 @@
 
 		// Preload required variables
-		$bbp_version    = bbp_get_version();
-		$content_length = strlen( $request );
-		$http_host      = $host;
-		$blog_charset   = get_option( 'blog_charset' );
-		$response       = '';
-		$errno          = null;
-		$errstr         = null;
+		$bbp_version  = bbp_get_version();
+		$http_host    = $host;
+		$blog_charset = get_option( 'blog_charset' );
+		$response     = '';
 
 		// Untque User Agent
@@ -643,67 +640,29 @@
 		}
 
-		// WP HTTP class is available
-		if ( function_exists( 'wp_remote_post' ) ) {
-
-			// Setup the arguments
-			$http_args = array(
-				'body'             => $request,
-				'headers'          => array(
-					'Content-Type' => 'application/x-www-form-urlencoded; charset=' . $blog_charset,
-					'Host'         => $host,
-					'User-Agent'   => $akismet_ua
-				),
-				'httpversion'      => '1.0',
-				'timeout'          => 15
-			);
-
-			// Where we are sending our request
-			$akismet_url = 'http://' . $http_host . $path;
-
-			// Send the request
-			$response    = wp_remote_post( $akismet_url, $http_args );
-
-			// Bail if the response is an error
-			if ( is_wp_error( $response ) ) {
-				return '';
-			}
-
-			// No errors so return response
-			return array( $response['headers'], $response['body'] );
-
-		// WP HTTP class is not available (Why not?)
-		} else {
-
-			// Header info to use with our socket
-			$http_request  = "POST {$path} HTTP/1.0\r\n";
-			$http_request .= "Host: {$host}\r\n";
-			$http_request .= "Content-Type: application/x-www-form-urlencoded; charset={$blog_charset}\r\n";
-			$http_request .= "Content-Length: {$content_length}\r\n";
-			$http_request .= "User-Agent: {$akismet_ua}\r\n";
-			$http_request .= "\r\n";
-			$http_request .= $request;
-
-			// Open a socket connection
-			if ( false !== ( $fs = @fsockopen( $http_host, $port, $errno, $errstr, 10 ) ) ) {
-
-				// Write our request to the pointer
-				fwrite( $fs, $http_request );
-
-				// Loop through pointer and compile a response
-				while ( !feof( $fs ) ) {
-					// One TCP-IP packet at a time
-					$response .= fgets( $fs, 1160 );
-				}
-
-				// Close our socket
-				fclose( $fs );
-
-				// Explode the response into usable data
-				$response = explode( "\r\n\r\n", $response, 2 );
-			}
-
-			// Return the response ('' if error/empty)
-			return $response;
-		}
+		// Setup the arguments
+		$http_args = array(
+			'body'             => $request,
+			'headers'          => array(
+				'Content-Type' => 'application/x-www-form-urlencoded; charset=' . $blog_charset,
+				'Host'         => $host,
+				'User-Agent'   => $akismet_ua
+			),
+			'httpversion'      => '1.0',
+			'timeout'          => 15
+		);
+
+		// Where we are sending our request
+		$akismet_url = 'http://' . $http_host . $path;
+
+		// Send the request
+		$response    = wp_remote_post( $akismet_url, $http_args );
+
+		// Bail if the response is an error
+		if ( is_wp_error( $response ) ) {
+			return '';
+		}
+
+		// No errors so return response
+		return array( $response['headers'], $response['body'] );
 	}
 
Index: /trunk/src/includes/forums/template.php
===================================================================
--- /trunk/src/includes/forums/template.php	(revision 5558)
+++ /trunk/src/includes/forums/template.php	(revision 5559)
@@ -2223,5 +2223,5 @@
 		// Get _POST data
 		if ( bbp_is_forum_form_post_request() && isset( $_POST['bbp_forum_content'] ) ) {
-			$forum_content = stripslashes( $_POST['bbp_forum_content'] );
+			$forum_content = wp_unslash( $_POST['bbp_forum_content'] );
 
 		// Get edit data
Index: /trunk/src/includes/replies/template.php
===================================================================
--- /trunk/src/includes/replies/template.php	(revision 5558)
+++ /trunk/src/includes/replies/template.php	(revision 5559)
@@ -2553,5 +2553,5 @@
 		// Get _POST data
 		if ( bbp_is_reply_form_post_request() && isset( $_POST['bbp_reply_content'] ) ) {
-			$reply_content = stripslashes( $_POST['bbp_reply_content'] );
+			$reply_content = wp_unslash( $_POST['bbp_reply_content'] );
 
 		// Get edit data
@@ -2748,5 +2748,5 @@
 		// Get _POST data
 		if ( bbp_is_reply_form_post_request() && isset( $_POST['bbp_reply_edit_reason'] ) ) {
-			$reply_edit_reason = stripslashes( $_POST['bbp_reply_edit_reason'] );
+			$reply_edit_reason = wp_unslash( $_POST['bbp_reply_edit_reason'] );
 
 		// No data
Index: /trunk/src/includes/topics/template.php
===================================================================
--- /trunk/src/includes/topics/template.php	(revision 5558)
+++ /trunk/src/includes/topics/template.php	(revision 5559)
@@ -3850,5 +3850,5 @@
 		// Get _POST data
 		if ( bbp_is_topic_form_post_request() && isset( $_POST['bbp_topic_title'] ) ) {
-			$topic_title = stripslashes( $_POST['bbp_topic_title'] );
+			$topic_title = wp_unslash( $_POST['bbp_topic_title'] );
 
 		// Get edit data
@@ -3861,5 +3861,5 @@
 		}
 
-		return apply_filters( 'bbp_get_form_topic_title', esc_attr( $topic_title ) );
+		return apply_filters( 'bbp_get_form_topic_title', $topic_title );
 	}
 
@@ -3887,5 +3887,5 @@
 		// Get _POST data
 		if ( bbp_is_topic_form_post_request() && isset( $_POST['bbp_topic_content'] ) ) {
-			$topic_content = stripslashes( $_POST['bbp_topic_content'] );
+			$topic_content = wp_unslash( $_POST['bbp_topic_content'] );
 
 		// Get edit data
@@ -3934,5 +3934,5 @@
 		// Get _POST data
 		if ( ( bbp_is_topic_form_post_request() || bbp_is_reply_form_post_request() ) && isset( $_POST['bbp_topic_tags'] ) ) {
-			$topic_tags = stripslashes( $_POST['bbp_topic_tags'] );
+			$topic_tags = wp_unslash( $_POST['bbp_topic_tags'] );
 
 		// Get edit data
@@ -3990,5 +3990,5 @@
 		}
 
-		return apply_filters( 'bbp_get_form_topic_tags', esc_attr( $topic_tags ) );
+		return apply_filters( 'bbp_get_form_topic_tags', $topic_tags );
 	}
 
@@ -4148,5 +4148,5 @@
 		// Get _POST data
 		if ( bbp_is_topic_form_post_request() && isset( $_POST['bbp_topic_edit_reason'] ) ) {
-			$topic_edit_reason = stripslashes( $_POST['bbp_topic_edit_reason'] );
+			$topic_edit_reason = wp_unslash( $_POST['bbp_topic_edit_reason'] );
 
 		// No data

Index: /trunk/src/includes/core/filters.php
===================================================================
--- /trunk/src/includes/core/filters.php	(revision 5558)
+++ /trunk/src/includes/core/filters.php	(revision 5559)
@@ -124,17 +124,17 @@
 add_filter( 'bbp_edit_forum_pre_content', 'balanceTags',     40 );
 
 // No follow and stripslashes on user profile links
 add_filter( 'bbp_get_reply_author_link',      'bbp_rel_nofollow' );
-add_filter( 'bbp_get_reply_author_link',      'stripslashes'     );
+add_filter( 'bbp_get_reply_author_link',      'wp_unslash'       );
 add_filter( 'bbp_get_topic_author_link',      'bbp_rel_nofollow' );
-add_filter( 'bbp_get_topic_author_link',      'stripslashes'     );
+add_filter( 'bbp_get_topic_author_link',      'wp_unslash'       );
 add_filter( 'bbp_get_user_favorites_link',    'bbp_rel_nofollow' );
-add_filter( 'bbp_get_user_favorites_link',    'stripslashes'     );
+add_filter( 'bbp_get_user_favorites_link',    'wp_unslash'       );
 add_filter( 'bbp_get_user_subscribe_link',    'bbp_rel_nofollow' );
-add_filter( 'bbp_get_user_subscribe_link',    'stripslashes'     );
+add_filter( 'bbp_get_user_subscribe_link',    'wp_unslash'       );
 add_filter( 'bbp_get_user_profile_link',      'bbp_rel_nofollow' );
-add_filter( 'bbp_get_user_profile_link',      'stripslashes'     );
+add_filter( 'bbp_get_user_profile_link',      'wp_unslash'       );
 add_filter( 'bbp_get_user_profile_edit_link', 'bbp_rel_nofollow' );
-add_filter( 'bbp_get_user_profile_edit_link', 'stripslashes'     );
+add_filter( 'bbp_get_user_profile_edit_link', 'wp_unslash'       );
 
 // Run filters on reply content
@@ -176,4 +176,8 @@
 add_filter( 'bbp_get_form_topic_edit_reason', 'esc_attr' );
 add_filter( 'bbp_get_form_topic_edit_reason', 'trim'     );
+add_filter( 'bbp_get_form_topic_title',       'esc_attr' );
+add_filter( 'bbp_get_form_topic_title',       'trim'     );
+add_filter( 'bbp_get_form_topic_tags',        'esc_attr' );
+add_filter( 'bbp_get_form_topic_tags',        'trim'     );
 
 // Add number format filter to functions requiring numeric output
@@ -124,17 +124,17 @@
 add_filter( 'bbp_edit_forum_pre_content', 'balanceTags',     40 );
 
-// No follow and stripslashes on user profile links
+// No follow and wp_unslash on user profile links
 add_filter( 'bbp_get_reply_author_link',      'bbp_rel_nofollow' );